@@ -1,10 +1,10 @@
+// -*- C++ -*-
+
 /* 
  * Gnome Chemistry Utils
  * element.cc 
  *
- * Copyright (C) 2002-2005
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2006 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -93,21 +93,21 @@ EltTable::EltTable()
 	Langs["it"] = _("Italian");
 	Langs["pl"] = _("Polish");
 	Langs["ru"] = _("Russian");
-	if (!(xml = xmlParseFile (DATADIR"/gchemutils-unstable/elements.xml")))
+	if (!(xml = xmlParseFile (DATADIR"/gchemutils/elements.xml")))
 	{
 		g_error (_("Can't find and read elements.xml"));
 	}
 	old_num_locale = g_strdup (setlocale (LC_NUMERIC, NULL));
 	setlocale (LC_NUMERIC, "C");
 	xmlNode* node = xml->children, *child;
-	if (strcmp ((const char*) node->name, "gpdata")) g_error (_("Uncorrect file format: elements.xml"));
+	if (strcmp ((const char*) node->name, "gpdata")) g_error (_("Incorrect file format: elements.xml"));
 	node = node->children;
 	Element* Elt;
 	while (node)
 	{
 		if (strcmp ((const char*) node->name, "text"))
 		{
-			if (strcmp ((const char*) node->name, "element")) g_error (_("Uncorrect file format: elements.xml"));
+			if (strcmp ((const char*) node->name, "element")) g_error (_("Incorrect file format: elements.xml"));
 			buf = (char*) xmlGetProp (node, (xmlChar*) "symbol");
 			num = (char*) xmlGetProp (node, (xmlChar*) "Z");
 			Elt = new Element (Z = atoi (num), buf);
@@ -356,7 +356,8 @@ unsigned Element::GetMaxBonds(gint Z)
 bool Element::GetRadius(GcuAtomicRadius* radius)
 {
 	Element* Elt = Table[radius->Z];
-	if (!Elt) return false;
+	if (!Elt || !Elt->m_radii.size ())
+		return false;
 	for (int i = 0; Elt->m_radii[i]; i++)
 	{
 		if (radius->type != Elt->m_radii[i]->type) continue;
@@ -415,25 +416,30 @@ double Element::GetWeight (int Z, int &prec)
 void Element::LoadRadii ()
 {
 	xmlDocPtr xml;
-	char *old_num_locale, *buf, *num, *dot, *end;
+	char *old_num_locale, *buf, *num;
 	unsigned char Z;
 	static bool loaded = false;
 	if (loaded)
 		return;
-	if (!(xml = xmlParseFile (DATADIR"/gchemutils-unstable/radii.xml")))
+	if (!(xml = xmlParseFile (DATADIR"/gchemutils/radii.xml")))
 	{
 		g_error (_("Can't find and read radii.xml"));
 	}
 	old_num_locale = g_strdup (setlocale (LC_NUMERIC, NULL));
 	setlocale (LC_NUMERIC, "C");
 	xmlNode* node = xml->children, *child;
-	if (strcmp ((const char*) node->name, "gpdata")) g_error (_("Uncorrect file format: radii.xml"));
+	if (strcmp ((const char*) node->name, "gpdata")) g_error (_("Incorrect file format: radii.xml"));
 	node = node->children;
 	Element* Elt;
+	set<string>::iterator it = units.find ("pm");
+	if (it == units.end ()) {
+		units.insert ("pm");
+		it = units.find ("pm");
+	}
 	while (node) {
 		if (strcmp ((const char*) node->name, "text"))
 		{
-			if (strcmp ((const char*) node->name, "element")) g_error (_("Uncorrect file format: radii.xml"));
+			if (strcmp ((const char*) node->name, "element")) g_error (_("Incorrect file format: radii.xml"));
 			num = (char*) xmlGetProp (node, (xmlChar*) "Z");
 			Elt = Table[Z = atoi (num)];
 			child = node->children;
@@ -486,9 +492,8 @@ void Element::LoadRadii ()
 						xmlFree (buf);
 					buf = (char*) xmlGetProp (child, (xmlChar*) "value");
 					if (buf) {
-						radius->value.value = strtod (buf, &end);
-						dot = strchr (buf, '.');
-						radius->value.prec = (dot)? end - dot - 1: 0;
+						ReadValue (buf, (GcuValue&) radius->value) ;
+						radius->value.unit = (*it).c_str ();
 						Elt->m_radii.push_back (radius);
 						xmlFree (buf);
 					} else
@@ -516,19 +521,19 @@ void Element::LoadElectronicProps ()
 	static bool loaded = false;
 	if (loaded)
 		return;
-	if (!(xml = xmlParseFile (DATADIR"/gchemutils-unstable/elecprops.xml")))
+	if (!(xml = xmlParseFile (DATADIR"/gchemutils/elecprops.xml")))
 	{
 		g_error (_("Can't find and read elecprops.xml"));
 	}
 	old_num_locale = g_strdup (setlocale (LC_NUMERIC, NULL));
 	setlocale (LC_NUMERIC, "C");
 	xmlNode* node = xml->children, *child;
-	if (strcmp ((const char*) node->name, "gpdata")) g_error (_("Uncorrect file format: elecprops.xml"));
+	if (strcmp ((const char*) node->name, "gpdata")) g_error (_("Incorrect file format: elecprops.xml"));
 	node = node->children;
 	Element* Elt;
 	while (node) {
 		if (strcmp ((const char*) node->name, "text")) {
-			if (strcmp ((const char*) node->name, "element")) g_error (_("Uncorrect file format: elecprops.xml"));
+			if (strcmp ((const char*) node->name, "element")) g_error (_("Incorrect file format: elecprops.xml"));
 			num = (char*) xmlGetProp (node, (xmlChar*) "Z");
 			Elt = Table[Z = atoi (num)];
 			child = node->children;
@@ -674,21 +679,21 @@ void Element::LoadIsotopes ()
 	static bool loaded = false;
 	if (loaded)
 		return;
-	if (!(xml = xmlParseFile (DATADIR"/gchemutils-unstable/isotopes.xml")))
+	if (!(xml = xmlParseFile (DATADIR"/gchemutils/isotopes.xml")))
 	{
 		g_error (_("Can't find and read isotopes.xml"));
 	}
 	old_num_locale = g_strdup (setlocale (LC_NUMERIC, NULL));
 	setlocale (LC_NUMERIC, "C");
 	xmlNode* node = xml->children, *child;
-	if (strcmp ((const char*) node->name, "gpdata")) g_error (_("Uncorrect file format: isotopes.xml"));
+	if (strcmp ((const char*) node->name, "gpdata")) g_error (_("Incorrect file format: isotopes.xml"));
 	node = node->children;
 	Element *Elt;
 	Isotope *Is;
 	int minA, maxA, niso;
 	while (node) {
 		if (strcmp ((const char*) node->name, "text")) {
-			if (strcmp ((const char*) node->name, "element")) g_error (_("Uncorrect file format: isotopes.xml"));
+			if (strcmp ((const char*) node->name, "element")) g_error (_("Incorrect file format: isotopes.xml"));
 			minA = maxA = niso = 0;
 			num = (char*) xmlGetProp (node, (xmlChar*) "Z");
 			Elt = Table[Z = atoi (num)];
